@@ -1,7 +1,9 @@
-# $Id: SLR.pm 15196 2008-12-17 08:19:17Z sendu $
+# $Id: SLR.pm 15564 2009-02-24 01:59:09Z cjfields $
 #
 # BioPerl module for Bio::Tools::Run::Phylo::SLR
 #
+# Please direct questions and support issues to <bioperl-l@bioperl.org> 
+#
 # Cared for by Albert Vilella <avilella-at-gmail-dot-com>
 #
 # Copyright Albert Vilella
@@ -76,6 +78,17 @@ the Bioperl mailing list.  Your participation is much appreciated.
   bioperl-l@bioperl.org                  - General discussion
   http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
 
+=head2 Support 
+ 
+Please direct usage questions or support issues to the mailing list:
+  
+L<bioperl-l@bioperl.org>
+  
+rather than to the module maintainer directly. Many experienced and 
+reponsive experts will be able look at the problem and quickly 
+address it. Please include a thorough description of the problem 
+with code and data examples if at all possible.
+
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
